function ECHAIM_FIRI2018, rootDir, lat, sza, f107, doy, alt
; lat= Scalar of Latitudes (Degrees North)
; sza = Scalar of Solar Zenith Angle (Degrees)
; f107 = Scalar of F10.7 Flux (sfu)
; doy = Scalar of Day of Year (days)
; alts = Vector of Altitudes (km)
; All inputs can be scalars or vectors

;load the save file
restore, rootDir+"E-CHAIM_FIRI.sav"

;set some limits
a = where(lat gt 60.0)
if a[0] ne -1 then lat[a] = 60.0
a = where(sza gt 130.0)
if a[0] ne -1 then sza[a] = 130.0
a = where(f107 gt 200.0)
if a[0] ne -1 then f107[a] = 200.0
a = where(f107 lt 75.0)
if a[0] ne -1 then f107[a] = 75.0

;Define output vector:
output = 0d0

; Identify applicable range:
if alt ge 150.0 or alt le 50.0 then return, output

;get the nearest neighbor point
wdiff = abs(w - f107) / abs(max(w))
vdiff = abs(v - doy) / abs(max(v))
xdiff = abs(x - sza) / abs(max(x))
ydiff = abs(y - lat) / abs(max(y))
zdiff = abs(z - alt) / abs(max(z))
q = wdiff+vdiff+xdiff+ydiff+zdiff
a=min(q,i)
ii = array_indices(w,i)

;now get each decimal index for each coordinate
xin = fltarr(5)
;F10.7
val0 = w[ii[0],ii[1],ii[2],ii[3],ii[4]]
if f107 eq val0 then begin
  xin[0] = ii[0]
endif else begin
  if val0 gt f107 then begin
    val1 = val0
    val0 = w[ii[0]-1,ii[1],ii[2],ii[3],ii[4]]
    xin[0] = ii[0]-1
  endif else begin
    val1 = w[ii[0]+1,ii[1],ii[2],ii[3],ii[4]]
    xin[0] = ii[0]
  endelse
  
  xin[0] += (f107 - val0)/(val1 - val0)
endelse

;DOY
val0 = v[ii[0],ii[1],ii[2],ii[3],ii[4]]
if doy eq val0 then begin
  xin[1] = ii[1]
endif else begin
  if val0 gt doy then begin
    val1 = val0
    val0 = v[ii[0]-1,ii[1]-1,ii[2],ii[3],ii[4]]
    xin[1] = ii[1]-1
  endif else begin
    val1 = v[ii[0],ii[1]+1,ii[2],ii[3],ii[4]]
    xin[1] = ii[1]
  endelse

  xin[1] += (doy - val0)/(val1 - val0)
endelse

;sza
val0 = x[ii[0],ii[1],ii[2],ii[3],ii[4]]
if sza eq val0 then begin
  xin[2] = ii[2]
endif else begin
  if val0 gt sza then begin
    val1 = val0
    val0 = x[ii[0],ii[1],ii[2]-1,ii[3],ii[4]]
    xin[2] = ii[2]-1
  endif else begin
    val1 = x[ii[0],ii[1],ii[2]+1,ii[3],ii[4]]
    xin[2] = ii[2]
  endelse

  xin[2] += (sza - val0)/(val1 - val0)
endelse

;lat
val0 = y[ii[0],ii[1],ii[2],ii[3],ii[4]]
if lat eq val0 then begin
  xin[3] = ii[3]
endif else begin
  if val0 gt lat then begin
    val1 = val0
    val0 = y[ii[0],ii[1],ii[2],ii[3]-1,ii[4]]
    xin[3] = ii[3]-1
  endif else begin
    val1 = y[ii[0],ii[1],ii[2],ii[3]+1,ii[4]]
    xin[3] = ii[3]
  endelse

  xin[3] += (lat - val0)/(val1 - val0)
endelse

;alt
val0 = z[ii[0],ii[1],ii[2],ii[3],ii[4]]
if alt eq val0 then begin
  xin[4] = ii[4]
endif else begin
  if val0 gt alt then begin
    val1 = val0
    val0 = z[ii[0],ii[1],ii[2],ii[3],ii[4]-1]
    xin[4] = ii[4]-1
  endif else begin
    val1 = z[ii[0],ii[1],ii[2],ii[3],ii[4]+1]
    xin[4] = ii[4]
  endelse

  xin[4] += (alt - val0)/(val1 - val0)
endelse

output = ninterpolate(denspertextra,[xin[0],xin[1],xin[2],xin[3],xin[4]])

if finite(output) eq 0 then output = 0d0

return, output
end