;Testing suite for IDL
;Used to test Matlab, C, and IDL against one another
;Will read a single input file which gives output type, lat, lon, alt, time inputs with options to create arrays of a given interval
;map and precip keywords will set map or precip to the ECHAIM call (map only if 'sat' is read from the file)

pro testSuite, map=map

;set the input and output files
file = "C:\Users\amccaffr\Documents\CHAIM\Release_C\ECHAIM-C\etc\ECHAIMInputs.dat"
fileout = "C:\Users\amccaffr\Documents\CHAIM\Release_C\ECHAIM-C\etc\outputIDL.dat"

;open the input file
openr, lun, file, /get_lun

h = '#'

;skip the header
while strmatch(h,'#*') eq 1 do begin
  readf, lun, h
endwhile

;create and read the inputs
lat = dblarr(3)
lon = dblarr(3)
alt = dblarr(3)
timeInt = 0d0
time = dblarr(2,6)
type = "z"
precip = 1d0
dregion = 1d0

reads, h, lat
readf, lun, lon, alt, timeInt, time, type, precip, dregion
free_lun, lun

;create the model input arrays
latout = lat[1]
if lat[0] ne 0 then begin
  for i=lat[1]+lat[0],lat[2]+lat[0]-0.0001,lat[0] do latout = [latout, i] 
endif else begin
  latout = [latout, lat[2]]
endelse

lonout = lon[1]
if lat[0] ne 0 then begin
  for i=lon[1]+lon[0],lon[2]+lon[0]-0.0001,lon[0] do lonout = [lonout, i]
endif else begin
  lonout = [lonout, lon[2]]
endelse

altout = alt[1]
if alt[0] ne 0 then begin
  for i=alt[1]+alt[0],alt[2],alt[0] do altout = [altout, i]
endif else begin
  altout = [altout, alt[2]]
endelse

jd = julday(time[0,1], time[0,2], time[0,0],time[0,3],time[0,4], time[0,5])
jde = julday(time[1,1], time[1,2], time[1,0],time[1,3],time[1,4], time[1,5])

if timeInt ne 0 then begin
  for i=jd+(timeInt/24d0),jde+(1d0/86400d0),(timeInt/24d0) do jd = [jd, i]
endif else begin
  jd = [jd, jde]
endelse



;print out the appropiate data
openw, lun, fileout, /get_lun

;run the model with appropiate keywords
;print out data depending on desired output
case type of
   "n": begin
        a = ECHAIM(latout, lonout, jd, altout)
        printf, lun, '1 ' + strtrim(n_elements(a.NmF2),2)
        printf, lun, a.NmF2, format="(f0)"
        end
         
   "m": begin
        a = ECHAIM(latout, lonout, jd, altout, /STORM_nmF2)
        printf, lun, '1 ' + strtrim(n_elements(a.NmF2),2)
        printf, lun, a.NmF2, format="(f0)"  
        end
   
   '2': begin
        a = ECHAIM(latout, lonout, jd, altout)
        printf, lun, '1 ' + strtrim(n_elements(a.hmF2),2)
        printf, lun, a.hmF2, format="(f0)"  
        end
        
   '1': begin
          a = ECHAIM(latout, lonout, jd, altout)
          printf, lun, '1 ' + strtrim(n_elements(a.hmF1),2)
          printf, lun, a.hmF1, format="(f0)"
        end
   
   "p": begin
    
        if precip*dregion eq 1 then begin
          a = ECHAIM(latout, lonout, jd, altout, /precip, /dregion)
        endif else if precip eq 1 then begin
          a = ECHAIM(latout, lonout, jd, altout, /precip)
        endif else if dregion eq 1 then begin
          a = ECHAIM(latout, lonout, jd, altout, /dregion)
        endif else begin
          a = ECHAIM(latout, lonout, jd, altout)
        endelse
        
        printf, lun, strtrim(n_elements(a.DENS[*,0]),2) + ' ' + strtrim(n_elements(a.DENS[0,*]),2)
        printf, lun, transpose(a.DENS), format="(" + strtrim(n_elements(a.DENS[0,*]),2) + "(f0,x))"
        end
   
   "r": begin
       if precip*dregion eq 1 then begin
         a = ECHAIM(latout, lonout, jd, altout, /precip, /dregion, /STORM_nmF2)
       endif else if precip eq 1 then begin
         a = ECHAIM(latout, lonout, jd, altout, /precip, /STORM_nmF2)
       endif else if dregion eq 1 then begin
         a = ECHAIM(latout, lonout, jd, altout, /dregion, /STORM_nmF2)
       endif else begin
         a = ECHAIM(latout, lonout, jd, altout, /STORM_nmF2)
       endelse

        printf, lun, strtrim(n_elements(a.DENS[*,0]),2) + ' ' + strtrim(n_elements(a.DENS[0,*]),2)
        printf, lun, transpose(a.DENS), format="(" + strtrim(n_elements(a.DENS[0,*]),2) + "(f0,x))" 
        end
   
   "s": begin
        if precip*dregion eq 1 then begin
         a = ECHAIM(latout, lonout, jd, altout, /precip, /dregion, /satellite)
       endif else if precip eq 1 then begin
         a = ECHAIM(latout, lonout, jd, altout, /precip, /satellite)
       endif else if dregion eq 1 then begin
         a = ECHAIM(latout, lonout, jd, altout, /dregion, /satellite)
       endif else begin
         a = ECHAIM(latout, lonout, jd, altout, /satellite)
       endelse
    
        printf, lun, '1 ' + strtrim(n_elements(a.DENS),2)
        printf, lun, a.DENS, format="(f0)"  
        end
       
   "a": begin
    
        if precip*dregion eq 1 then begin
         a = ECHAIM(latout, lonout, jd, altout, /precip, /dregion, /satellite, /storm_NmF2)
       endif else if precip eq 1 then begin
         a = ECHAIM(latout, lonout, jd, altout, /precip, /satellite, /storm_NmF2)
       endif else if dregion eq 1 then begin
         a = ECHAIM(latout, lonout, jd, altout, /dregion, /satellite, /storm_NmF2)
       endif else begin
         a = ECHAIM(latout, lonout, jd, altout, /satellite, /storm_NmF2)
       endelse
    
        printf, lun, '1 ' + strtrim(n_elements(a.DENS),2)
        printf, lun, a.DENS, format="(f0)"  
        end
endcase

free_lun, lun


end
