function dipole_tilt_calc,IYR,IMONTH,IDAY,IHOUR,IMIN,ISEC;,epoch=epoch

idoy = floor(julday(IMONTH,IDAY,IYR,IHOUR,IMIN,ISEC)-julday(01,01,IYR,00,00,00))+1
iday = idoy

; Modified by David R. Themens August 17th, 2020: Updated code to work beyond 2020.
; Modified by David R. Themens April 18th, 2016: Turned the code into a function for dipole tilt calculation
; Also extended the coefficients back to 1900 from 1965. Full range available is now 1900-2020.  

; NOTE: To update, append new IGRF G and H coefficients to end of if/else statement and update extrapolation else. 
;       Information can be found in the Tsyganenko GEOPACK Fortran code.
 
; ------------- NOTE: all inputs to this code are scalars. This code will not work with vectors or arrays.

;C
;C
;C  THIS IS A MODIFIED VERSION OF THE SUBROUTINE RECOMP WRITTEN BY
;C  N.A. TSYGANENKO.  SINCE I WANT TO USE IT IN PLACE OF SUBROUTINE
;C  RECALC I HAVE RENAMED THIS ROUTINE RECALC AND ELIMINATED THE
;C  ORIGINAL RECALC FROM THIS VERSION OF THE GEOPACK.F PACKET. THIS
;C  WAY ALL ORIGINAL CALLS TO RECALC WILL CONTINUE TO WORK WITHOUT 
;C  HAVING TO CHANGE THEM TO CALLS TO RECOMP.
;C
;C
;C  AN ALTERNATIVE VERSION OF THE SUBROUTINE RECALC FROM THE GEOPACK PACKAGE
;C  BASED ON A DIFFERENT APPROACH TO DERIVATION OF ROTATION MATRIX ELEMENTS
;C
;C THIS SUBROUTINE WORKS BY 20% FASTER THAN RECALC AND IS EASIER TO UNDERSTAND
;C
;C   ################################################
;C   #  WRITTEN BY  N.A. TSYGANENKO ON DEC.1, 1991  #
;C   ################################################
;C
;C
;C  Modified by:  Mauricio Peredo
;C      Hughes STX at NASA/GSFC Code 695
;C      September 1992
;C
;C
;C  Modified to accept dates up to year 2000 and updated IGRF
;C  coeeficients for 1985.
;       
;       RCJ 02/2001 modified to accept dates up to year 2005 and
; updated IGRF coefficients for 2000.
;C
;C   OTHER SUBROUTINES CALLED BY THIS ONE: SUN
;C
;C     IYR = YEAR NUMBER (FOUR DIGITS)
;C     IDAY = DAY OF MONTH
;C     IMONTH = MONTH OF YEAR (JANUARY = 1)
;C     IHOUR = HOUR OF DAY (00 TO 23)
;C     MIN = MINUTE OF HOUR (00 TO 59)
;C     ISEC = SECONDS OF DAY(00 TO 59)
;C
; IMPLICIT NONE

IYE = 0l
IDE = 0l
IPR = 0l

;C
;C  IYE AND IDE ARE THE CURRENT VALUES OF YEAR AND DAY NUMBER
;C
      IY=IYR
      IDE=IDAY
;      IF ((IYR EQ IYE) AND (IDAY EQ IDE))THEN GOTO, JUMP5
      IF(IY LT 1900)THEN IY=1900
;      IF(IY GT 2015)THEN IY=2015
      IF(IY GT 2020)THEN IY=2025
;C
;C  
;C  WE ARE RESTRICTED BY THE INTERVAL 1900-2025,
;C  FOR WHICH THE IGRF COEFFICIENTS ARE KNOWN; IF IYR IS OUTSIDE THIS INTERVAL
;C   THE SUBROUTINE GIVES A WARNING (BUT DOES NOT REPEAT IT AT THE NEXT CALLS)
;C
;      IF(IY NE IYR) AND (IPR EQ 0)THEN PRINT,FORMAT=FORMAT10,IYR,IY
      IF(IY NE IYR)THEN IPR=1
      IYE=IY
;C
;C  LINEAR INTERPOLATION OF THE GEODIPOLE MOMENT COMPONENTS BETWEEN THE
;C  VALUES FOR THE NEAREST EPOCHS:
;C

  IF (IY LT 1905) THEN BEGIN      ;!1900-1905
     F2=(FLOAT(IY) + FLOAT(IDAY-1)/365.25-1900.)/5.
     F1=1.-F2
     G10=31543.*F1+31464.*F2
     G11=-2298.*F1-2298.*F2
     H11=5922.*F1+5909.*F2
  ENDIF ELSE IF (IY LT 1910) THEN BEGIN      ;!1905-1910
     F2=(FLOAT(IY) + FLOAT(IDAY-1)/365.25-1905.)/5.
     F1=1.-F2
     G10=31464.*F1+31354.*F2
     G11=-2298.*F1-2297.*F2
     H11=5909.*F1+5898.*F2
  ENDIF ELSE IF (IY LT 1915) THEN BEGIN      ;!1910-1915
     F2=(FLOAT(IY) + FLOAT(IDAY-1)/365.25-1910.)/5.
     F1=1.-F2
     G10=31354.*F1+31212.*F2
     G11=-2297.*F1-2306.*F2
     H11=5898.*F1+5875.*F2
  ENDIF ELSE IF (IY LT 1920) THEN BEGIN      ;!1915-1920
     F2=(FLOAT(IY) + FLOAT(IDAY-1)/365.25-1915.)/5.
     F1=1.-F2
     G10=31212.*F1+31060.*F2
     G11=-2306.*F1-2317.*F2
     H11=5875.*F1+5845.*F2
  ENDIF ELSE IF (IY LT 1925) THEN BEGIN      ;!1920-1925
     F2=(FLOAT(IY) + FLOAT(IDAY-1)/365.25-1920.)/5.
     F1=1.-F2
     G10=31060.*F1+30926.*F2
     G11=-2317.*F1-2318.*F2
     H11=5845.*F1+5817.*F2  
  ENDIF ELSE IF (IY LT 1930) THEN BEGIN      ;!1925-1930
     F2=(FLOAT(IY) + FLOAT(IDAY-1)/365.25-1925.)/5.
     F1=1.-F2
     G10=30926.*F1+30805.*F2
     G11=-2318.*F1-2316.*F2
     H11=5817.*F1+5808.*F2
  ENDIF ELSE IF (IY LT 1935) THEN BEGIN      ;!1930-1935
     F2=(FLOAT(IY) + FLOAT(IDAY-1)/365.25-1930.)/5.
     F1=1.-F2
     G10=30805.*F1+30715.*F2
     G11=-2316.*F1-2306.*F2
     H11=5808.*F1+5812.*F2
  ENDIF ELSE IF (IY LT 1940) THEN BEGIN      ;!1935-1940
     F2=(FLOAT(IY) + FLOAT(IDAY-1)/365.25-1935.)/5.
     F1=1.-F2
     G10=30715.*F1+30654.*F2
     G11=-2306.*F1-2292.*F2
     H11=5812.*F1+5821.*F2
  ENDIF ELSE IF (IY LT 1945) THEN BEGIN      ;!1940-1945
     F2=(FLOAT(IY) + FLOAT(IDAY-1)/365.25-1940.)/5.
     F1=1.-F2
     G10=30654.*F1+30594.*F2
     G11=-2292.*F1-2285.*F2
     H11=5821.*F1+5810.*F2
  ENDIF ELSE IF (IY LT 1950) THEN BEGIN      ;!1945-1950
     F2=(FLOAT(IY) + FLOAT(IDAY-1)/365.25-1945.)/5.
     F1=1.-F2
     G10=30594.*F1+30554.*F2
     G11=-2285.*F1-2250.*F2
     H11=5810.*F1+5815.*F2
  ENDIF ELSE IF (IY LT 1955) THEN BEGIN      ;!1950-1955
     F2=(FLOAT(IY) + FLOAT(IDAY-1)/365.25-1950.)/5.
     F1=1.-F2
     G10=30554.*F1+30500.*F2
     G11=-2250.*F1-2215.*F2
     H11=5815.*F1+5820.*F2
  ENDIF ELSE IF (IY LT 1960) THEN BEGIN      ;!1955-1960
     F2=(FLOAT(IY) + FLOAT(IDAY-1)/365.25-1955.)/5.
     F1=1.-F2
     G10=30500.*F1+30421.*F2
     G11=-2215.*F1-2169.*F2
     H11=5820.*F1+5791.*F2
  ENDIF ELSE IF (IY LT 1965) THEN BEGIN      ;!1960-1965
     F2=(FLOAT(IY) + FLOAT(IDAY-1)/365.25-1960.)/5.
     F1=1.-F2
     G10=30421.*F1+30334.*F2
     G11=-2169.*F1-2119.*F2
     H11=5791.*F1+5776.*F2
  ENDIF ELSE IF (IY LT 1970) THEN BEGIN     ;!1965-1970
     F2=(FLOAT(IY) + FLOAT(IDAY-1)/365.25-1965.)/5.
     F1=1.-F2
     G10=30334.*F1+30220.*F2
     G11=-2119.*F1-2068.*F2
     H11=5776.*F1+5737.*F2
  ENDIF ELSE IF (IY LT 1975) THEN BEGIN   ;!1970-1975
     F2=(FLOAT(IY)+FLOAT(IDAY-1)/365.25-1970.)/5.
     F1=1.-F2
     G10=30220.*F1+30100.*F2
     G11=-2068.*F1-2013.*F2
     H11=5737.*F1+5675.*F2
  ENDIF ELSE IF (IY LT 1980) THEN BEGIN   ;!1975-1980
     F2=(FLOAT(IY)+FLOAT(IDAY-1)/365.25-1975)/5.
     F1=1.-F2
     G10=30100.*F1+29992.*F2
     G11=-2013.*F1-1956.*F2
     H11=5675.*F1+5604.*F2
  ENDIF ELSE IF (IY LT 1985) THEN BEGIN   ;!1980-1985
     F2=(FLOAT(IY)+FLOAT(IDAY-1)/365.25-1980.)/5.
     F1=1.-F2
     G10=29992.*F1+29873.*F2
     G11=-1956.*F1-1905.*F2
     H11=5604.*F1+5500.*F2
  ENDIF ELSE IF (IY LT 1990) THEN BEGIN   ;!1985-1990
     F2=(FLOAT(IY)+FLOAT(IDAY-1)/365.25-1985.)/5.
     F1=1.-F2
     G10=29873.*F1+29775.*F2
     G11=-1905.*F1-1848.*F2
     H11=5500.*F1+5406.*F2
  ENDIF ELSE IF (IY LT 1995) THEN BEGIN   ;!1990-1995
;TJK added use of FLOAT    F2=(IY+IDAY/365D0-1990.)/5.
     F2=(FLOAT(IY)+FLOAT(IDAY-1)/365.25-1990.)/5.
     F1=1.-F2
     G10=29775.*F1+29692.*F2
     G11=-1848.*F1-1784.*F2
     H11=5406.*F1+5306.*F2
  ENDIF ELSE IF (IY LT 2000) THEN BEGIN   ;!1995-2000
;TJK added use of FLOAT    F2=(IY+IDAY/365D0-1995.)/5.
     F2=(FLOAT(IY)+FLOAT(IDAY-1)/365.25-1995.)/5.
     F1=1.-F2
     G10=29692.*F1+29619.4*F2
     G11=-1784.*F1-1728.2*F2
     H11=5306.*F1+5186.1*F2
  ENDIF ELSE IF (IY LT 2005) THEN BEGIN   ;!2000-2005
     F2=(FLOAT(IY)+FLOAT(IDAY-1)/365.25-2000.)/5.
     F1=1.-F2
     G10=29619.4*F1+29554.63*F2
     G11=-1728.2*F1-1669.05*F2
     H11=5186.1*F1+5077.99*F2
  ENDIF ELSE IF (IY LT 2010) THEN BEGIN   ;!2005-2010
     F2=(FLOAT(IY)+FLOAT(IDAY-1)/365.25-2005.)/5.
     F1=1.-F2
     G10=29554.63*F1+29496.57*F2
     G11=-1669.05*F1-1586.42*F2
     H11=5077.99*F1+4944.26*F2
  ENDIF ELSE IF (IY LT 2015) THEN BEGIN   ;!2010-2015
     F2=(FLOAT(IY)+FLOAT(IDAY-1)/365.25-2010.)/5.
     F1=1.-F2
     G10=29496.57*F1+29441.46*F2
     G11=-1586.42*F1-1501.77*F2
     H11=4944.26*F1+4795.99*F2
  ENDIF ELSE IF (IY LT 2020) THEN BEGIN  ;!2015-2020  
     F2=(FLOAT(IY)+FLOAT(IDAY-1)/365.25-2015)/5.
     F1=1.-F2
     G10=29441.46*F1+29404.8*F2
     G11=-1501.77*F1-1450.9*F2
     H11=4795.99*F1+4652.5*F2
;
;   LINEAR EXTRAPOLATION BEYOND 2020 BY USING SECULAR VELOCITY COEFFICIENTS:
;
  ENDIF ELSE BEGIN        ;!2020-2025
;TJK added use of float and divide by 366 instead of 365
;    DT=IY+IDAY/365D0-2010.
     DT=FLOAT(IY)+FLOAT(IDAY-1)/365.25-2020.
     G10=29404.8-5.7*DT      ;! HERE G10 HAS OPPOSITE SIGN TO THAT IN IGRF TABLES (i.e. DG(1))
     G11=-1450.9+7.4*DT  ; multiplying by DT are elements from igrf??s.dat: -G10 (yes,negative),  (i.e. -DG(2))
     H11=4652.5-25.9*DT    ; G11 and H11. (i.e. DH(1))
  ENDELSE
;C
;C  NOW CALCULATE THE COMPONENTS OF THE UNIT VECTOR EzMAG IN GEO COORD.SYSTEM:
;C   SIN(TETA0)*COS(LAMBDA0), SIN(TETA0)*SIN(LAMBDA0), AND COS(TETA0)
;C         ST0 * CL0                ST0 * SL0                CT0
;C
      SQ=G11^2+H11^2
      SQQ=SQRT(SQ)
      SQR=SQRT(G10^2+SQ)
      SL0=-H11/SQQ
      CL0=-G11/SQQ
      ST0=SQQ/SQR
      CT0=G10/SQR
      STCL=ST0*CL0
      STSL=ST0*SL0
      CTSL=CT0*SL0
      CTCL=CT0*CL0
;C
;C      THE CALCULATIONS ARE TERMINATED IF ONLY GEO-MAG TRANSFORMATION
;C       IS TO BE DONE  (IHOUR>24 IS THE AGREED CONDITION FOR THIS CASE):
;C
;JUMP5:   IF (IHOUR GT 24)THEN RETURN
;C

Farp =  SUN(IY,IDAY,IHOUR,IMIN,ISEC) ; SUN.PRO MODIFIED TO FUNCTION FORM BY DAVID R. THEMENS

GST = Farp(2)
SLONG = Farp(3)
SRASN = Farp(0)
SDEC = Farp(1)

;C
;C  S1,S2, AND S3 ARE THE COMPONENTS OF THE UNIT VECTOR EXGSM=EXGSE IN THE
;C   SYSTEM GEI POINTING FROM THE EARTH'S CENTER TO THE SUN:
;C
      S1=COS(SRASN)*COS(SDEC)
      S2=SIN(SRASN)*COS(SDEC)
      S3=SIN(SDEC)
      CGST=COS(GST)
      SGST=SIN(GST)
;C
;C  DIP1, DIP2, AND DIP3 ARE THE COMPONENTS OF THE UNIT VECTOR EZSM=EZMAG
;C   IN THE SYSTEM GEI:
;C
      DIP1=STCL*CGST-STSL*SGST
      DIP2=STCL*SGST+STSL*CGST
      DIP3=CT0
;C
;C  NOW CALCULATE THE COMPONENTS OF THE UNIT VECTOR EYGSM IN THE SYSTEM GEI
;C   BY TAKING THE VECTOR PRODUCT D x S AND NORMALIZING IT TO UNIT LENGTH:
;C
      Y1=DIP2*S3-DIP3*S2
      Y2=DIP3*S1-DIP1*S3
      Y3=DIP1*S2-DIP2*S1
      Y=SQRT(Y1*Y1+Y2*Y2+Y3*Y3)
      Y1=Y1/Y
      Y2=Y2/Y
      Y3=Y3/Y
;C
;C   THEN IN THE GEI SYSTEM THE UNIT VECTOR Z = EZGSM = EXGSM x EYGSM = S x Y
;C    HAS THE COMPONENTS:
;C
      Z1=S2*Y3-S3*Y2
      Z2=S3*Y1-S1*Y3
      Z3=S1*Y2-S2*Y1
;C
;C    THE VECTOR EZGSE (HERE DZ) IN GEI HAS THE COMPONENTS (0,-SIN(DELTA),
;C     COS(DELTA)) = (0.,-0.397823,0.917462); HERE DELTA = 23.44214 DEG FOR
;C   THE EPOCH 1978 (SEE THE BOOK BY GUREVICH OR OTHER ASTRONOMICAL HANDBOOKS).
;C    HERE THE MOST ACCURATE TIME-DEPENDENT FORMULA IS USED:
;C
      DJ=365*(IY-1900)+FIX((IY-1901)/4) +float(IDAY) -0.5 +ISEC/86400D0
      T=DJ/36525D0
      OBLIQ=(23.45229-0.0130125*T)/57.2957795
      DZ1=0.
      DZ2=-SIN(OBLIQ)
      DZ3=COS(OBLIQ)
;C
;C  THEN THE UNIT VECTOR EYGSE IN GEI SYSTEM IS THE VECTOR PRODUCT DZ x S :
;C
      DY1=DZ2*S3-DZ3*S2
      DY2=DZ3*S1-DZ1*S3
      DY3=DZ1*S2-DZ2*S1
;C
;C   THE ELEMENTS OF THE MATRIX GSE TO GSM ARE THE SCALAR PRODUCTS:
;C   CHI=EM22=(EYGSM,EYGSE), SHI=EM23=(EYGSM,EZGSE), EM32=(EZGSM,EYGSE)=-EM23,
;C     AND EM33=(EZGSM,EZGSE)=EM22
;C
      CHI=Y1*DY1+Y2*DY2+Y3*DY3
      SHI=Y1*DZ1+Y2*DZ2+Y3*DZ3
      HI=ASIN(SHI)
;C
;C    TILT ANGLE: PSI=ARCSIN(DIP,EXGSM)
;C
      SPS=DIP1*S1+DIP2*S2+DIP3*S3
      CPS=SQRT(1.-SPS^2)
      PSI=ASIN(SPS)

  return, psi

      END