function lt_and_mlat_calc_david_for_monthly_medians, latitudes, longitudes, altitudes,time_vector,root_dir

if !version.os_family eq 'Windows' then OS_flag = '\' else OS_flag = '/'

err_codes = strarr(n_elements(latitudes))

; --- Start by loading the solar activity and geomagnetic activity data

dir_kp_ap_SSN = root_dir+'KP_AP'+OS_flag

;cd, dir_kp_ap_SSN

jul_day_in = time_vector

;Restore the DB file for F10.7, KP, and IG
restore, root_dir + "IDL_DB.sav"

;set KP AP structure
kp_str = create_struct('jul_hres', data.threehour_jd, 'kp_hres', data.kp, 'ap_hres', data.ap)

;set F10 data
flux_ind = data.F10
flux_day = data.daily_jd

;end of measurement and forecasted data
flux_day_max = metadata.F10_max
forecasts_max = flux_day[-1]

; --- Read in IG index:

ig_jul = data.monthly_jd
ig_indices = data.ig
k = where(ig_jul gt metadata.IG_MAX)
ig12_indices = data.ig(k)



; Smooth F10.7
flux_ind1 = data.F10_27
flux_in1_81 = data.F10_81
flux_in1_365 = flux_ind + !values.d_nan ;not used, but needed as inputs
hres_kp = kp_str.kp_hres
hres_ap = kp_str.ap_hres
ap_8 = data.ap_8
hres_jul = kp_str.jul_hres

; Interpolate F10.7 to input times:
F107_outs = interpol(flux_ind1,flux_day,jul_day_in)
F107_1_outs = interpol(flux_ind,flux_day,jul_day_in)
F107_81_outs = interpol(flux_in1_81,flux_day,jul_day_in)
F107_365_outs = F107_outs + !values.d_nan ;interpol(flux_in1_365,flux_day,jul_day_in)

; Create NOAA flag:
check_f107_range = where(jul_day_in gt flux_day_max,cntovers)
if cntovers gt 0 then begin
;forecasts =read_noaa_f107_prediction_file('NOAA F10.7 Prediction.txt',root_dir)
;F107_outs(check_f107_range) = interpol(forecasts.b,forecasts.a,jul_day_in(check_f107_range))
;F107_1_outs(check_f107_range) = interpol(forecasts.b,forecasts.a,jul_day_in(check_f107_range))
;F107_81_outs(check_f107_range) = interpol(forecasts.b,forecasts.a,jul_day_in(check_f107_range))
;F107_365_outs(check_f107_range) = interpol(forecasts.b,forecasts.a,jul_day_in(check_f107_range))
err_codes(check_f107_range) = err_codes(check_f107_range)+'F'

; Error code and mark periods past last forecast f10.7 flux record and before the first F10.7 flux record:

check_f107_forecast = where(jul_day_in gt forecasts_max or jul_day_in lt min(flux_day,/nan) or jul_day_in lt julday(01,01,1950,00,00,00),cntovers); 1950 is the lower limit
if cntovers gt 0 then begin
F107_outs(check_f107_forecast) = !values.F_NAN
F107_1_outs(check_f107_forecast) = !values.F_NAN
F107_81_outs(check_f107_forecast) = !values.F_NAN
F107_365_outs(check_f107_forecast) = !values.F_NAN
err_codes(check_f107_forecast) = err_codes(check_f107_forecast)+'E'
endif

endif




SSN_outs = !values.F_NAN


; Get max IG day
a = where(finite(ig_indices))
ig_max = metadata.ig_max

check_ig = where(jul_day_in gt ig_max,cntig) ;get the index associated with the last finite IG value
if cntig gt 0 then err_codes(check_ig) = err_codes(check_ig)+'C'

;Do the interpolation now
ig_outs = interpol(ig_indices,ig_jul,jul_day_in)
ig12_outs = !values.d_nan

check_ig12 = where(jul_day_in gt max(ig_jul,/nan) or jul_day_in lt min(ig_jul,/nan) or jul_day_in lt julday(01,01,1944,00,00,00),cntig12) ; Lower Time limit of 1944.
if cntig12 gt 0 then begin
  ig_outs(check_ig12) = !values.F_NAN
  err_codes(check_ig12) = err_codes(check_ig12)+'G'
endif


;interpolate kp to input days
kp_outs = interpol(hres_kp,hres_jul,jul_day_in)
ap_outs8 = interpol(ap_8,hres_jul,jul_day_in)

; --- Prepare for AACGM Wraping:

;IGRF_file_directory = 'C:\Users\David\Desktop\For Heaviside\AACGM COEFS\AACGMv2'
IGRF_file_directory = root_dir+'AACGM COEFS'+OS_flag+'idl_aacgm_v23'
R = 6378.1

caldat, time_vector,month_uses ,day_uses,year_uses,hour_uses,minute_uses,second_uses

yrsec = (julday(month_uses,day_uses,year_uses,hour_uses,minute_uses,second_uses)-julday(01,01,year_uses,00,00,00))*24.0*3600.0

;cd, IGRF_file_directory

; --- NOTE: This AACGM code can only be used for a single position at a time. Insert loop.

mlat_outs = fltarr(n_elements(latitudes)) ;magnetic latitude
mlon_outs = fltarr(n_elements(latitudes)) ;magnetic longitude
mlt_outs = fltarr(n_elements(latitudes)) ; contrary to its name this is solar local time.
mmlt_outs = fltarr(n_elements(latitudes)) ; this is magnetic local time.
mlt_juls_outs = dblarr(n_elements(latitudes)) ; julian local times.
modip_outs = fltarr(n_elements(latitudes)) ; 
inclen_outs = fltarr(n_elements(latitudes))
zenith_outs = fltarr(n_elements(latitudes))

;counti = 0.0
for i = 0L, n_elements(latitudes)-1L do begin

;if (i)mod(floor(n_elements(latitudes)/300.0)) eq 0 then begin
;print, [counti,300]
;counti = counti +1
;endif

latitude = latitudes(i)
longitude = longitudes(i)
altitude = altitudes(i)
year_use = year_uses(i)
month_use = month_uses(i)
day_use = day_uses(i)
hour_use = hour_uses(i)
minute_use = minute_uses(i)
second_use = second_uses(i)
yrsec_use = yrsec(i)

error_array = AACGM_v2_SetDateTime(year_use,month_use,day_use,hour_use,minute_use,second_use)
mcoords = cnvcoord_v2(latitude,longitude,altitude)
mmlt = mlt_v2(mcoords(1))

inclination = atan(2.0*tan(mcoords(0)*!pi/180.0))
modip = atan((inclination/sqrt(cos(latitude*!PI/180.0))))*180.0/!PI
inclination = inclination*180.0/!PI
modip_outs(i) = modip
inclen_outs(i) = inclination
;print, 'the'

;---- Back to useful stuff:

mlat_outs(i) = mcoords(0)
mlon_outs(i) = mcoords(1)
mmlt_outs(i) = mmlt

if (year_use gt 1900) then yr=year_use-1900

dy=floor(yrsec_use/(24.0*3600.0))+1;round(julday(month_use,day_use,year_use,00,00,00)-julday(01,00,year_use,00,00,00));
ut=float(yrsec_use-((dy-1)*24.0*3600.0))/3600.0;(time_vector(i)-julday(month_use,day_use,year_use,00,00,00));
zensun_echaim,dy,ut,latitude,longitude,zenith1,azimuth,solfac,sunrise=sunrise, latsun=latsun1,lonsun=lonsun1
zenith_outs(i) = zenith1
;et = eqn_of_time2(lonsun1, yr)/3600.0

mlt = (longitude - lonsun1) /15.0 + 12.0;+et
mlt_hour = floor(mlt)
mlt_minute = floor((mlt-mlt_hour)*60.0)
mlt_second = (((mlt-mlt_hour)*60.0)-mlt_minute)*60.0
mlt_juls = julday(month_use,day_use,year_use,mlt_hour,mlt_minute,mlt_second)
if (mlt ge 24.0) then mlt=mlt-24.0;
if (mlt lt 0.0) then mlt=mlt+24.0;

mlt_outs(i) = mlt
mlt_juls_outs(i) = mlt_juls

;print, 'the'

;if finite(mlt,/nan) then begin
;print, 'the'
;endif

;if i eq 143L then begin
;print, 'the'
;endif

endfor


out_struct = {A:mlt_outs,B:mlat_outs,C:mlon_outs, D: modip_outs, E: inclen_outs, F:zenith_outs,G:F107_outs,H:SSN_outs,J:kp_outs,K:mlt_juls_outs, $
  L:ig_outs, M:ig12_outs, N:F107_81_outs, O:F107_365_outs, P:mmlt_outs, Q:F107_1_outs,errors:err_codes,kp_struct:kp_str, ap8:ap_outs8}
;out_struct = {A:mlt_outs,B:mlat_outs,C:mlon_outs, D: modip_outs, E: inclen_outs, F:zenith_outs,G:F107_outs,H:SSN_outs,J:kp_outs,K:mlt_juls_outs, L:ig_outs, M:ig12_outs, N:F107_81_outs, O:F107_365_outs, Q:F107_1_outs}

;get metadata info
if tag_exist(data,'metadate') then begin
  out_struct = create_Struct(out_struct, 'dbDate', data.metadate)
endif else begin
  out_struct = create_Struct(out_struct, 'dbDate', 0.0)
endelse

return, out_struct

;print, 'the'

end