function SUN,IYR,IDAY,IHOUR,IMIN,ISEC;,GST,SLONG,SRASN,SDEC,epoch=epoch

; Modified by David Themens April 18th, 2016: Turned code into a function and modified for sole use with dipole_tilt_calc.pro code.

;TJK added the next three lines for y2k - based on Scott Boardsen's changes.
;      iyr = long(iyr)
;      if iyr lt 50 then iyr = 2000 + iyr
;      if iyr ge 50 and iyr lt 1900 then iyr = 1900 + iyr
;C
;C  CALCULATES FOUR QUANTITIES NECESSARY FOR COORDINATE TRANSFORMATIONS
;C  WHICH DEPEND ON SUN POSITION (AND, HENCE, ON UNIVERSAL TIME AND SEASON)
;C
;C-------  INPUT PARAMETERS:
;C  IYR,IDAY,IHOUR,MIN,ISEC -  YEAR, DAY, AND UNIVERSAL TIME IN HOURS, MINUTES,
;C    AND SECONDS  (IDAY=1 CORRESPONDS TO JANUARY 1).
;C
;C-------  OUTPUT PARAMETERS:
;C  GST - GREENWICH MEAN SIDEREAL TIME, SLONG - LONGITUDE ALONG ECLIPTIC
;C  SRASN - RIGHT ASCENSION,  SDEC - DECLINATION  OF THE SUN (RADIANS)
;C  THIS SUBROUTINE HAS BEEN COMPILED FROM: RUSSELL C.T., COSM.ELECTRO-
;C  DYN., 1971, V.2,PP.184-196.
;C
;C
;C                   AUTHOR: Gilbert D. Mead
;C
;C
; IMPLICIT NONE

; REAL GST,SLONG,SRASN,SDEC,RAD,T,VL,G,OBLIQ,SOB,SLP,SIND,
;    1       COSD,SC

; INTEGER IYR,IDAY,IHOUR,IMIN,ISEC

;      DOUBLE PRECISION DJ,FDAY
      RAD=57.295779513d0
;      IF((IYR LT 1901) OR (IYR GT 2099))THEN RETURN
      FDAY=(IHOUR*3600D0+IMIN*60D0+ISEC)/86400.D0
      DJ=365d0*(IYR-1900)+FIX((IYR-1901)/4)+float(IDAY)-0.5D0+FDAY
      T=DJ/36525D0
      VL=(279.696678D0+0.9856473354D0*DJ) MOD 360.D0
      GST=( (279.690983D0+.9856473354D0*DJ+360.*FDAY+180.) MOD 360.D0)/RAD
      G=( (358.475845D0+0.985600267D0*DJ) MOD 360.D0)/RAD
      SLONG=(VL+(1.91946D0-0.004789D0*T)*SIN(G)+0.020094D0*SIN(2.*G))/RAD
      IF(SLONG GT 6.2831853D0)THEN SLONG=SLONG-6.2831853D0
      IF (SLONG LT 0D0)THEN SLONG=SLONG+6.2831853D0
      OBLIQ=(23.45229D0-0.0130125D0*T)/RAD
      SOB=SIN(OBLIQ)
      SLP=SLONG-9.924D-5
;C
;C   THE LAST CONSTANT IS A CORRECTION FOR THE ANGULAR ABERRATION  DUE TO
;C   THE ORBITAL MOTION OF THE EARTH
;C
      SIND=SOB*SIN(SLP)
      COSD=SQRT(1.-SIND^2)
      SC=SIND/COSD
      SDEC=ATAN(SC)
      SRASN=3.141592654D0-atan(COS(OBLIQ)/SOB*SC,-COS(SLP)/COSD)
      

RETURN, [SRASN,SDEC,GST,SLONG]
END