function updateLocalDB, force
;This function checks the age of the local DB
;if the DB file is older than the last expected update time, the DB file
;available on the ECHAIM website is downloaded and will overwrite the current DB file
;
;Output is used to know what the function did
;0 = database file was updated after updateTime
;1 = current time is less than updateTime
;2 = current time is later than updateTime AND DB file was not updated after updateTime
;   The DB file was updated
;3 = DB file was forced to update without any checks

dbFile = file_dirname(routine_filepath()) + path_sep() + 'IDL_DB.sav'

wgetCmd = "wget https://chain-new.chain-project.net/echaim_downloads/DBFiles/IDL_DB.sav -O " + dbFile
wc = checkwget()

;if user forces download of the file
if force then begin
  if wc then begin
    spawn, wgetCmd
  endif else begin
  a=wget('https://chain-new.chain-project.net/echaim_downloads/DBFiles/IDL_DB.sav', filename=dbFile)
  end
  return, 3
endif

;If the DB file is missing then download it
if ~file_test(dbFile) then begin
  if wc then begin
    spawn, wgetCmd
  endif else begin
    a=wget('https://chain-new.chain-project.net/echaim_downloads/DBFiles/IDL_DB.sav', filename=dbFile)
  end
  return, 2
endif

;file modification time (julian date)
fileTime = file_modtime(dbFile)

;current time
currentTime = systime(/seconds,/utc)

;update time
;May 21 2020 11:30 UTC
tt = 1590060600d0
d = systime(/seconds,/utc)
i = floor((d - tt) / 86400d0)
updateTime = systime(/seconds,/utc,elapsed=tt+(i*86400d0))

;The DB file was last update after updateTime
if fileTime ge updateTime then return, 0

;Current time is before updateTime
if currentTime lt updateTime then return, 1

;Haven't returned yet, so the DB file is older than updateTime and current time is later, so the DB file needs to be updated
if wc then begin
    spawn, wgetCmd
  endif else begin
  a=wget('https://chain-new.chain-project.net/echaim_downloads/IDL_DB.sav', filename=dbFile)
end
return, 2



end